@@ -101,8 +101,8 @@ custom.eqn <- function (directory=getwd(), cus.formula = "none", crop = "n", ext
       b5 <- raster (paste0 (directory, "/", sat_fold, "_B5.TIF"))
       b4 <- raster (paste0 (directory, "/", sat_fold, "_B4.TIF"))
       b3 <- raster (paste0 (directory, "/", sat_fold, "_B3.TIF"))
-      stak <- stack(c(b5,b4,b3))
-      plotRGB(stak)
+      stak <- raster::stack (c (b5, b4, b3))
+      plotRGB (stak, scale = 65536)
       print("Please define your extent from the map in plot preview for further processing")
       print("You can click on the top left of custom subset region followed by the bottom right")
       ext <- drawExtent()
