@@ -86,8 +86,8 @@ dn2toa <- function (directory= getwd(), crop = "n", ext2crop = "none",b1=1,b2=1,
       b5 <- raster (paste0 (directory, "/", sat_fold, "_B5.TIF"))
       b4 <- raster (paste0 (directory, "/", sat_fold, "_B4.TIF"))
       b3 <- raster (paste0 (directory, "/", sat_fold, "_B3.TIF"))
-      stak <- stack(c(b5,b4,b3))
-      plotRGB(stak)
+      stak <- raster::stack(c(b5,b4,b3))
+      plotRGB(stak, scale = 65536)
       print("Please define your extent from the map in plot preview for further processing")
       print("You can click on the top left of custom subset region followed by the bottom right")
       ext <- drawExtent()
